@@ -13,7 +13,7 @@
 # limitations under the License.
 
 """
-Common utils for agents
+Common utils for connectors
 """
 from datetime import datetime
 import io
@@ -45,4 +45,4 @@ def get_name(prefix):
     Construct name with current timestamp
     """
     time_stamp = datetime.utcnow().strftime("%H-%M-%S")
-    return '{}-{}'.format(prefix, time_stamp)
+    return f"{prefix}-{time_stamp}"
